aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-frame.h
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2007-06-13 22:36:58 +0000
committerGerald Combs <gerald@wireshark.org>2007-06-13 22:36:58 +0000
commitd1a745f27b47ab4c7247c984eff543284012bba2 (patch)
tree8a506e8fa478ef9fae7313d51ba808a22c59180a /epan/dissectors/packet-frame.h
parente3fc848842ac6868cda63cae40ca41ee31e94bce (diff)
Add support for PPI (the Per-Packet Information header), described at
http://www.cacetech.com/documents/PPI_Header_format_1.0.pdf . svn path=/trunk/; revision=22094
Diffstat (limited to 'epan/dissectors/packet-frame.h')
-rw-r--r--epan/dissectors/packet-frame.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/epan/dissectors/packet-frame.h b/epan/dissectors/packet-frame.h
index ca62c10aa6..cc81fc5831 100644
--- a/epan/dissectors/packet-frame.h
+++ b/epan/dissectors/packet-frame.h
@@ -36,7 +36,7 @@ void show_exception(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
void
show_reported_bounds_error(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
-/*
+/*
* Routine used to register frame end routine. The routine should only
* be registred when the dissector is used in the frame, not in the
* proto_register_XXX function.
@@ -50,8 +50,13 @@ register_frame_end_routine(void (*func)(void));
*/
extern int proto_malformed;
-/* following variables are exported from libwireshark.dll.
- * Thus we need a special declaration.
+/*
+ * The frame dissector and the PPI dissector both use this
+ */
+extern dissector_table_t wtap_encap_dissector_table;
+
+/* following variables are exported from libwireshark.dll.
+ * Thus we need a special declaration.
*/
WS_VAR_IMPORT int proto_frame;
WS_VAR_IMPORT int hf_frame_arrival_time;